@@ -1,11 +1,11 @@
 """Aliases and exports."""
 from .action_request import Actions
 from .precondition_request import Preconditions
-from .assertions import BodyAssertions, StatusAssertions
+from .assertions import BodyAssertions, HeadersAssertions, StatusAssertions
 
 
 class __Request(
-    Actions, BodyAssertions, Preconditions, StatusAssertions
+    Actions, BodyAssertions, HeadersAssertions, Preconditions, StatusAssertions
 ):
     ...
 
