@@ -14,6 +14,15 @@ class Actions(BaseRequest):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self._response = None
+
+    @property
+    def response(self):
+        return self._response
+
+    @response.setter
+    def response(self, value):
+        self._response = value
 
     @when
     def perform(self):
@@ -25,4 +34,5 @@ class Actions(BaseRequest):
             params=self.params,
             data=dumps(self.body),
             headers=self.headers,
+            auth=self.basic_auth
         )
